nummod number of models based on which the coefficient is computed
nu threshold based on which the coefficient is computed
Arguments
object
result of spar.cv function of class 'spar.cv'.
nummod
optional number of models used to form coefficients
nu
optional threshold level used to form coefficients
opt_par
one of c("1se","best"), chooses whether to select the
best pair of nus and nummods according to cross-validated
(CV) measure, or the sparsest solution within one sd of that optimal
CV measure;
ignored when nummod and nu are given
aggregate
character one of c("mean", "median", "none"). If set to "none"
the coefficients are not aggregated over the marginal models, otherwise
the coefficients are aggregated using the specified method (mean or median).
Defaults to mean aggregation.