Learn R Programming

spareg (version 1.1.1)

generate_cw: Sparse Embedding Matrix

Description

Sparse Embedding Matrix

Usage

generate_cw(rp, m, included_vector, x = NULL, y = NULL)

Value

(possibly sparse) matrix with m rows and length(included_vector) columns.

Arguments

m

goal dimension, which will be randomly sampled in the SPAR algorithm

included_vector

integer vector of column indices for the variables to be included in the random projection. These indices are produced in the screening step of the SPAR algorithm.

x

matrix of predictors

y

vector of response variable