Learn R Programming

spareg (version 1.1.1)

generate_gaussian: Gaussian Random Projection Matrix

Description

Gaussian Random Projection Matrix

Usage

generate_gaussian(rp, m, included_vector, x = NULL, y = NULL)

Value

matrix with m rows and length(included_vector) columns sampled from the normal distribution.

Arguments

rp

object of class 'randomprojection'

m

goal dimension, which will be randomly sampled in the SPAR algorithm

included_vector

integer vector of column indices for the variables to be included in the random projection. These indices are produced in the screening step of the SPAR algorithm.

x

matrix of predictors

y

vector of response variable