generate_scrcoef_marglik: Generate screening coefficient based on marginal likelihood in univariate GLMs
Description
Generate screening coefficient based on marginal likelihood in univariate GLMs
Usage
generate_scrcoef_marglik(y, x, object)
Value
vector of screening coefficients of length p
Arguments
- y
vector of responses
- x
matrix of predictors
- object
'screencoef' object