Sparse Embedding Matrix
generate_cw(rp, m, included_vector, x = NULL, y = NULL)(possibly sparse) matrix with m rows and
length(included_vector) columns.
goal dimension, which will be randomly sampled in the SPAR algorithm
integer vector of column indices for the variables to be included in the random projection. These indices are produced in the screening step of the SPAR algorithm.
matrix of predictors
vector of response variable