Gaussian Random Projection Matrix
generate_gaussian(rp, m, included_vector, x = NULL, y = NULL)matrix with m rows and
length(included_vector) columns sampled from the normal distribution.
object of class 'randomprojection'
goal dimension, which will be randomly sampled in the SPAR algorithm
integer vector of column indices for the variables to be included in the random projection. These indices are produced in the screening step of the SPAR algorithm.
matrix of predictors
vector of response variable