Creates an object class 'sparmodel' using arguments passed by user.
Usage
spar_glm(..., control = list())
Value
object of class 'sparmodel' which is a list with elements
name (character)
control (list of controls passed as an argument)
model_fun function for estimating the model coefficients and the intercept.
This function should have arguments y, vector of standardized responses,
z, a matrix of projected predictors in each marginal model, and
object, which is a 'sparmodel' object. Returns a list with
two elements: gammas which is the vector of regression coefficients
for the projected predictors and intercept which is the intercept of the model
Arguments
...
includes arguments which can be passed as attributes to the
'sparmodel' object
control
list of controls to be passed to the model function